package com.vendor.burn.ui;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.define.IErasable;
import com.vendor.burn.model.define.IFastbootProgressMonitor;
import com.vendor.burn.model.define.IUploadable;
import com.vendor.burn.model.devices.IUIAdapter;
import com.vendor.burn.model.devices.IUIAdapterable;
import com.vendor.burn.model.event.EventType;
import com.vendor.burn.model.event.FastbootEvent;
import com.vendor.burn.model.event.IFastbootEventListener;
import com.vendor.burn.preferences.FastbootPreferences;
import com.vendor.burn.ui.IDEHelper;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.burn.views.FastbootView;
import java.util.List;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Layout;
import org.eclipse.swt.widgets.TabItem;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;

public abstract class BurnComposite extends Composite implements IFastbootEventListener, IUIAdapterable {
  protected static final String LABEL_BURN = Messages.BurnComposite_Burn_Text;
  
  protected static final String LABEL_DDRCHECK = Messages.BurnComposite_DdrCheck_Text;
  
  protected static final String LABEL_UPLOAD = Messages.BurnComposite_Upload_Text;
  
  protected static final String LABEL_ERASE = Messages.BurnComposite_Erase_Text;
  
  protected static final String LABEL_FALSH_TYPE = Messages.BurnComposite_LABEL_FALSHTYPE;
  
  protected static final String LABEL_FALSH_ID = Messages.BurnComposite_LABEL_FALSHID;
  
  protected static final String LABEL_BROWSE = Messages.BurnComposite_Browse_Text;
  
  protected static final String LABEL_SAVE = Messages.BurnComposite_Save_Text;
  
  protected static final String LABEL_FILE = Messages.BurnComposite_LABEL_FILE;
  
  protected static final String LABEL_CREATE_USB_PACKAGE = Messages.BurnComposite_Create_Usb_Package_Text;
  
  protected static final String LABEL_MAKE_NAND_IMAGE = Messages.PartitionComposite_Button_MakeNandImage;
  
  protected static final int CREATE_IMAGE_BUTTON_WIDTH = 200;
  
  private IUIAdapter adapter;
  
  protected IBurner burner;
  
  protected IFastbootProgressMonitor progressMonitor;
  
  public BurnComposite(Composite parent, int style, IBurner burner) {
    super(parent, style);
    this.burner = burner;
    _setLayout(createLayout());
    createContents(this);
    IFastbootProgressMonitor monitor = getProgressMonitor();
    monitor.addListener(this);
  }
  
  public BurnComposite(Composite parent, int style, IBurner burner2, TabItem tabItem2) {
    super(parent, style);
    this.burner = burner2;
    _setLayout(createLayout());
    createContents(this);
    IFastbootProgressMonitor monitor = getProgressMonitor();
    monitor.addListener(this);
  }
  
  private void _setLayout(Layout layout) {
    super.setLayout(layout);
  }
  
  protected boolean startInfo() {
    boolean isStart = true;
    if (FastbootView.isChipBranchSeries0() && 
      ToolUtils.isJTagTransferMode(getBurner().getBurnContext().getTransferWay()))
      return MessageDialog.openConfirm(getShell(), Messages.FASTBOOT_MessageDialog_Title, Messages.ERROR_INFO_Start_JTAG); 
    return isStart;
  }
  
  protected void burn() {
    IBurner burner = getBurner();
    if (checkStatus(burner.checkBeforeBurn())) {
      if (!startInfo()) {
        enableButtons();
        return;
      } 
      IFastbootProgressMonitor monitor = getProgressMonitor();
      monitor.getEvent().setBurner(getBurner());
      burner.burn(monitor);
    } else {
      enableButtons();
    } 
  }
  
  protected void enableButtons() {}
  
  protected boolean checkStatus(IStatus status) {
    if (status == Status.CANCEL_STATUS)
      return false; 
    boolean valid = (status == null || status.isOK());
    if (!valid)
      MessageDialog.openWarning(getShell(), Messages.FASTBOOT_MessageDialog_Title, status.getMessage()); 
    return valid;
  }
  
  protected abstract void createContents(Composite paramComposite);
  
  protected abstract Layout createLayout();
  
  protected boolean isAlertWhenDone() {
    return FastbootPreferences.isDialogOn();
  }
  
  protected void erase() {
    IBurner burner = getBurner();
    if (burner instanceof IErasable) {
      IErasable eraseable = (IErasable)burner;
      if (!startInfo()) {
        enableButtons();
        return;
      } 
      if (getBurner() instanceof com.vendor.burn.model.devices.burners.EmmcBurner) {
        IFastbootProgressMonitor monitor = getProgressMonitor();
        monitor.getEvent().setBurner(getBurner());
        eraseable.erase(monitor);
      } else if (checkStatus(eraseable.checkBeforeErase())) {
        IFastbootProgressMonitor monitor = getProgressMonitor();
        monitor.getEvent().setBurner(getBurner());
        eraseable.erase(monitor);
      } else {
        enableButtons();
      } 
    } 
  }
  
  protected void eraseAll() {
    IBurner burner = getBurner();
    if (burner instanceof IErasable) {
      IErasable eraseable = (IErasable)burner;
      if (!startInfo()) {
        enableButtons();
        return;
      } 
      if (burner.getBurnContext().getTransferWay() == TransferWay.GPT) {
        MessageDialog.openWarning(getShell(), Messages.FASTBOOT_MessageDialog_Title, Messages.AddressComposite_Gpt_NotSupport_EraseAll);
        enableButtons();
        return;
      } 
      IFastbootProgressMonitor monitor = getProgressMonitor();
      if (getBurner() instanceof com.vendor.burn.model.devices.burners.CommonBurner) {
        monitor.getEvent().setBurner(getBurner());
        eraseable.eraseAll(monitor);
      } else if (getBurner() instanceof com.vendor.burn.model.devices.burners.EmmcBurner) {
        monitor.getEvent().setBurner(getBurner());
        eraseable.erase(monitor);
      } else {
        monitor.getEvent().setBurner(getBurner());
        eraseable.eraseAll(monitor);
      } 
    } 
  }
  
  public IBurner getBurner() {
    return this.burner;
  }
  
  public IFastbootProgressMonitor getProgressMonitor() {
    if (this.progressMonitor == null)
      if (ToolUtils.isCmdLine()) {
        this.progressMonitor = IFastbootProgressMonitor.PROGRESSMONITORCMDLINE;
      } else {
        this.progressMonitor = IFastbootProgressMonitor.PROGRESSMONITORCOMPOSITE;
      }  
    return this.progressMonitor;
  }
  
  public void updateLength(long length) {}
  
  public final void setLayout(Layout layout) {}
  
  protected void upload() {
    IBurner burner = getBurner();
    if (burner instanceof IUploadable) {
      IUploadable uploadable = (IUploadable)burner;
      if (!startInfo()) {
        enableButtons();
        return;
      } 
      IStatus checkBeforeUpload = uploadable.checkBeforeUpload();
      if (checkBeforeUpload != null && checkBeforeUpload.getSeverity() == 8) {
        enableButtons();
        return;
      } 
      if (checkStatus(checkBeforeUpload)) {
        uploadable.upload(getProgressMonitor());
      } else {
        enableButtons();
      } 
    } 
  }
  
  public void started(FastbootEvent event) {
    IWorkbench workbench = PlatformUI.getWorkbench();
    IWorkbenchWindow activeWorkbenchWindow = workbench.getActiveWorkbenchWindow();
    IWorkbenchPage activePage = activeWorkbenchWindow.getActivePage();
    IViewPart findView = activePage.findView("org.eclipse.ui.console.ConsoleView");
    if (findView != null) {
      activePage.setPartState(activePage.getReference((IWorkbenchPart)findView), 2);
    } else {
      try {
        activePage.showView("org.eclipse.ui.console.ConsoleView");
      } catch (PartInitException partInitException) {}
    } 
    disableUI();
  }
  
  protected void disableUI() {
    if (!isDisposed() && getParent() != null)
      getParent().setEnabled(false); 
  }
  
  public void finished(FastbootEvent event) {
    enableUI();
    if (event.getBurner() != getBurner())
      return; 
    if (isAlertWhenDone()) {
      String message = null;
      EventType type = event.getType();
      if (type == null)
        return; 
      if (event.isUserCanceled()) {
        message = event.getMessage();
        if (message == null)
          message = "User Cancelled!"; 
        IDEHelper.preOpenDialog();
        MessageDialog.openInformation(getShell(), Messages.FASTBOOT_MessageDialog_Title, message);
        return;
      } 
      message = getMessageForAllEvent(event, message, type);
      if (message != null) {
        IDEHelper.preOpenDialog();
        String tipsMessage = message;
        if (event.isSuccess()) {
          Display.getDefault().asyncExec((Runnable)new Object(this, tipsMessage));
        } else {
          Display.getDefault().asyncExec((Runnable)new Object(this, tipsMessage));
        } 
      } 
    } 
  }
  
  private String getMessageForAllEvent(FastbootEvent event, String message, EventType type) {
    if (type == EventType.BURN) {
      message = getMessaageForBurn(event);
    } else if (type == EventType.ERASE) {
      message = getMessageForErase(event);
    } else if (type == EventType.UPLOAD) {
      message = getMessageForUpload(event);
    } else if (type == EventType.CREATE_IMAGE) {
      message = getMessageForCreateImage(event);
    } else if (type == EventType.CREATE_USB_PACKAGE) {
      message = getMessageForCreateUSB(event);
    } 
    return message;
  }
  
  private String getMessageForCreateUSB(FastbootEvent event) {
    String message = event.getMessage();
    if (event.isSuccess()) {
      message = Messages.BurnComposite_Create_Usb_Package_Success;
    } else if (message == null) {
      message = Messages.BurnComposite_Create_Usb_Package_Failed;
    } 
    return message;
  }
  
  private String getMessageForCreateImage(FastbootEvent event) {
    String message = event.getMessage();
    if (event.isSuccess())
      message = Messages.BurnComposite_Create_Image_Success; 
    return message;
  }
  
  private String getMessageForUpload(FastbootEvent event) {
    String message = event.getMessage();
    if (event.isSuccess()) {
      message = Messages.BurnComposite_Upload_Message_Success;
    } else if (message == null) {
      message = Messages.BurnComposite_Upload_Message_Failed;
    } 
    return message;
  }
  
  private String getMessageForErase(FastbootEvent event) {
    String message = event.getMessage();
    if (event.isSuccess()) {
      message = Messages.BurnComposite_Erase_Message_Success;
    } else if (message == null) {
      message = Messages.BurnComposite_Erase_Message_Failed;
    } 
    return message;
  }
  
  private String getMessaageForBurn(FastbootEvent event) {
    String message = event.getMessage();
    if (event.isSuccess()) {
      String totalBurnTime = event.getTotalBurnTime();
      boolean isPartition = (event.getBurner() instanceof com.vendor.burn.model.devices.burners.PartitionBurner || event.getBurner() instanceof com.vendor.burn.model.devices.burners.EmmcBurner);
      if (isPartition) {
        boolean totalBurnTimeVaild = (totalBurnTime != null && !totalBurnTime.equalsIgnoreCase(""));
        if (totalBurnTimeVaild) {
          message = Messages.BurnComposite_Burn_Message_Success_And_Time + Messages.BurnComposite_Burn_Message_Success_And_Time + ".";
        } else {
          message = Messages.BurnComposite_Burn_Message_Success;
        } 
      } else {
        message = Messages.BurnComposite_Burn_Message_Success;
      } 
    } 
    return message;
  }
  
  protected void enableUI() {
    if (!isDisposed() && getParent() != null)
      getParent().setEnabled(true); 
  }
  
  public void hightLight(List<PartitionItem> parts) {}
  
  public IUIAdapter getUIAdapter() {
    return this.adapter;
  }
  
  public void setUIAdapter(IUIAdapter adapter) {
    this.adapter = adapter;
    this.burner.getBurnContext().setUIAdapter(adapter);
  }
}
